import React from 'react';
import { Chart, Interval, Tooltip } from 'bizcharts';
import { DataSet } from '@antv/data-set';

const data = [
  { value: 251, name: '大事例一', subName: '子事例一' },
  { value: 1041, name: '大事例三', subName: '子事例二' },
  { value: 610, name: '大事例二', subName: '子事例二' },
  { value: 434, name: '大事例二', subName: '子事例四' },
  { value: 335, name: '大事例二', subName: '子事例五' },
  { value: 250, name: '大事例三', subName: '子事例二' },
];
const dv1 = new DataSet.View().source(data);
dv1
  .transform({
    type: 'aggregate', // 别名summary
    fields: ['name'], // 统计字段集
    operations: ['count'], // 统计操作集
    as: ['计数'], // 存储字段集
    groupBy: ['name'], // 分组字段集
  })
  .transform({
    type: 'sort-by',
    fields: ['计数'], // 根据指定的字段集进行排序，与lodash的sortBy行为一致
    order: 'DESC', // 默认为 ASC，DESC 则为逆序
  });
console.log(dv1.rows);

const dv2 = new DataSet.View().source(data);
dv2
  .transform({
    type: 'aggregate', // 别名summary
    fields: ['value'], // 统计字段集
    operations: ['mean'], // 统计操作集
    as: ['平均值'], // 存储字段集
    groupBy: ['subName'], // 分组字段集
  })
  .transform({
    type: 'sort-by',
    fields: ['平均值'], // 根据指定的字段集进行排序，与lodash的sortBy行为一致
    order: 'DESC', // 默认为 ASC，DESC 则为逆序
  });
console.log(dv2.rows);
function Demo() {
  return (
    <>
      <Chart
        height={300}
        width={400}
        autoFit
        data={dv1.rows}
        interactions={['active-region']}
        padding="auto"
      >
        <Interval position="name*计数" />
        <Tooltip shared />
      </Chart>
      <Chart
        height={300}
        width={400}
        autoFit
        data={dv2.rows}
        interactions={['active-region']}
        padding="auto"
      >
        <Interval position="subName*平均值" />
        <Tooltip shared />
      </Chart>
    </>
  );
}
export default Demo;
// dv.transform({
//   type: 'aggregate', // 别名summary
//   fields: ['name', 'value'], // 统计字段集
//   operations: ['count', 'mean'], // 统计操作集
//   as: ['计数', '平均值'], // 存储字段集
//   groupBy: ['name'], // 分组字段集
// }).transform({
//   type: 'sort-by',
//   fields: ['计数'], // 根据指定的字段集进行排序，与lodash的sortBy行为一致
//   order: 'DESC', // 默认为 ASC，DESC 则为逆序
// });
// const data = [
//   {
//     ID: '215341',
//     loginName: 'gcwqgps',
//     userName: 'gcwqgps',
//     systemType: 'solution',
//     terminal: 'Browser',
//     IP: '192.168.10.150',
//     logTime: '2020/11/23 18:56:27',
//   },
//   {
//     ID: '215342',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:17:51',
//   },
//   {
//     ID: '215343',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:41:12',
//   },
//   {
//     ID: '215344',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:42:04',
//   },
//   {
//     ID: '215345',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:45:56',
//   },
//   {
//     ID: '215346',
//     loginName: 'panda',
//     userName: '熊猫智慧水务',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '192.168.10.150',
//     logTime: '2020/11/23 19:55:20',
//   },
//   {
//     ID: '215347',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:55:39',
//   },
//   {
//     ID: '215348',
//     loginName: '17671748304',
//     userName: '邹小仙',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '192.168.10.150',
//     logTime: '2020/11/23 20:01:34',
//   },
//   {
//     ID: '215349',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 20:16:51',
//   },
// ];
