import React from 'react';
import { Form, DatePicker, Table, Row, Col, Button } from 'antd';
import { Chart, Interval, Tooltip, Axis } from 'bizcharts';
import { DataSet } from '@antv/data-set';

const data = [
  { value: 251, name: '接口名称一', subName: '子事例一' },
  { value: 1041, name: '接口名称三', subName: '子事例二' },
  { value: 610, name: '接口名称二', subName: '子事例二' },
  { value: 434, name: '接口名称二', subName: '子事例四' },
  { value: 335, name: '接口名称二', subName: '子事例五' },
  { value: 250, name: '接口名称三', subName: '子事例二' },
];
const columns = Object.keys(data[0]).map(key => ({
  title: key,
  dataIndex: key,
  key,
}));
// console.log(Object.keys(data[0]));
const scale = {
  name: {
    alias: '接口名称', // 别名
  },
  subName: {
    alias: '名称', // 别名
  },
};
const dv1 = new DataSet.View().source(data);
dv1
  .transform({
    type: 'aggregate', // 别名summary
    fields: ['name'], // 统计字段集
    operations: ['count'], // 统计操作集
    as: ['计数'], // 存储字段集
    groupBy: ['name'], // 分组字段集
  })
  .transform({
    type: 'sort-by',
    fields: ['计数'], // 根据指定的字段集进行排序，与lodash的sortBy行为一致
    order: 'DESC', // 默认为 ASC，DESC 则为逆序
  });
console.log(dv1.rows);

const dv2 = new DataSet.View().source(data);
dv2
  .transform({
    type: 'aggregate', // 别名summary
    fields: ['value'], // 统计字段集
    operations: ['mean'], // 统计操作集
    as: ['平均值'], // 存储字段集
    groupBy: ['subName'], // 分组字段集
  })
  .transform({
    type: 'sort-by',
    fields: ['平均值'], // 根据指定的字段集进行排序，与lodash的sortBy行为一致
    order: 'DESC', // 默认为 ASC，DESC 则为逆序
  });
console.log(dv2.rows);

function Demo() {
  const [timeForm] = Form.useForm();
  return (
    <>
      <Form style={{ padding: '0px 6px' }} form={timeForm}>
        <Row>
          <Col span={4}>
            <Form.Item name="startTime" label="起始时间">
              <DatePicker showTime format="YYYY-MM-DD HH:mm:ss" />
            </Form.Item>
          </Col>
          <Col span={4}>
            <Form.Item name="endTime" label="结束时间">
              <DatePicker showTime format="YYYY-MM-DD HH:mm:ss" />
            </Form.Item>
          </Col>
          <Col span={12}>
            <Button
              onClick={() => {
                // timeForm.setFieldsValue({ startTime: '2020-11-12 12:12:12' });
              }}
            >
              近1小时
            </Button>
            <Button>近6小时</Button>
            <Button>近12小时</Button>
            <Button>近1天</Button>
            <Button>近1周</Button>
          </Col>
        </Row>
      </Form>
      <Row style={{ padding: '10px' }}>
        <Col span={8}>
          <Chart
            height={300}
            width={400}
            autoFit
            data={dv1.rows}
            interactions={['active-region']}
            padding="auto"
            scale={scale}
          >
            <Axis name="name" title />
            <Axis name="计数" title />
            <Interval position="name*计数" />
            <Tooltip shared />
          </Chart>
        </Col>
        <Col span={8}>
          <Chart
            height={300}
            width={400}
            autoFit
            data={dv2.rows}
            interactions={['active-region']}
            padding="auto"
            scale={scale}
          >
            <Axis name="subName" title />
            <Axis name="平均值" title />
            <Interval position="subName*平均值" />
            <Tooltip shared />
          </Chart>
        </Col>
      </Row>
      <Table
        size="small"
        bordered
        columns={columns || []}
        dataSource={data}
        // loading={tableLoading}
        scroll={{ x: 'max-content' }}
        pagination={{
          showTotal: (total, range) =>
            `第${range[0]}-${range[1]} 条/共 ${total} 条`,
          pageSizeOptions: [10, 20, 50, 100],
          defaultPageSize: 20,
          showQuickJumper: true,
          showSizeChanger: true,
        }}
      />
    </>
  );
}
export default Demo;
// dv.transform({
//   type: 'aggregate', // 别名summary
//   fields: ['name', 'value'], // 统计字段集
//   operations: ['count', 'mean'], // 统计操作集
//   as: ['计数', '平均值'], // 存储字段集
//   groupBy: ['name'], // 分组字段集
// }).transform({
//   type: 'sort-by',
//   fields: ['计数'], // 根据指定的字段集进行排序，与lodash的sortBy行为一致
//   order: 'DESC', // 默认为 ASC，DESC 则为逆序
// });
// const data = [
//   {
//     ID: '215341',
//     loginName: 'gcwqgps',
//     userName: 'gcwqgps',
//     systemType: 'solution',
//     terminal: 'Browser',
//     IP: '192.168.10.150',
//     logTime: '2020/11/23 18:56:27',
//   },
//   {
//     ID: '215342',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:17:51',
//   },
//   {
//     ID: '215343',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:41:12',
//   },
//   {
//     ID: '215344',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:42:04',
//   },
//   {
//     ID: '215345',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:45:56',
//   },
//   {
//     ID: '215346',
//     loginName: 'panda',
//     userName: '熊猫智慧水务',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '192.168.10.150',
//     logTime: '2020/11/23 19:55:20',
//   },
//   {
//     ID: '215347',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 19:55:39',
//   },
//   {
//     ID: '215348',
//     loginName: '17671748304',
//     userName: '邹小仙',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '192.168.10.150',
//     logTime: '2020/11/23 20:01:34',
//   },
//   {
//     ID: '215349',
//     loginName: 'luojian',
//     userName: 'gwcj',
//     systemType: 'city',
//     terminal: 'Browser',
//     IP: '127.0.0.1',
//     logTime: '2020/11/23 20:16:51',
//   },
// ];
