import React, { useEffect, useState } from 'react';
import {
  message,
  notification,
  Popconfirm,
  Form,
  Tree,
  Tooltip,
  Modal,
  Input,
  Button,
  Spin,
} from 'antd';
import {
  FileAddTwoTone,
  FolderAddTwoTone,
  FolderFilled,
  FileOutlined,
  DeleteTwoTone,
} from '@ant-design/icons';
import PicturesWall from '@/components/Upload/index';
import classnames from 'classnames';
import {
  miniAppSiteTree,
  getMiniAppModuleTree,
  addMenu,
  getMenuInfo,
  deleteMenu,
  editMenu,
} from '@/services/mobileConfig/api';
import styles from './miniMenu.less';
import AddForm from './AddForm';
import EditForm from './editForm';

const MiniMenu = props => {
  const [flag, setFlag] = useState(1); // 刷新标志
  const [treeFlage, setTreeFlag] = useState(true);
  const [treeData, setTreeData] = useState([]); // 树的数据
  const [loading, setLoading] = useState(false); // 加载
  const [menuID, setMenuID] = useState(''); // 选中的树ID
  const [saveID, setSaveID] = useState(''); // 保存选择的树id
  const [nodeType, setNodeType] = useState(''); // 选中的节点类型
  const [info, setInfo] = useState({});
  const [addVisible, setAddVisible] = useState(false); // 新增弹窗
  const [addTwoVisible, setAddTwoVisible] = useState(false); // 编辑弹窗
  const [addFlag, setAddFlag] = useState('root'); // 设置新增标志
  const [nodeObj, setNodeObj] = useState({});
  const [addType, setAddType] = useState(''); // 添加下级类型
  // 获取菜单树
  useEffect(() => {
    updateTrees();
  }, [flag]);

  // 获取菜单信息
  useEffect(() => {
    getInfo();
  }, [menuID]);

  // 更新树
  const updateTrees = () => {
    setLoading(true);
    miniAppSiteTree({
      _version: 9999,
      _dc: new Date().getTime(),
      node: -2,
      userMode: 'super',
      select: '',
    })
      .then(res => {
        if (res.length > 0) {
          setLoading(false);
          const result = res[0].children[0].children[2].children;
          setTreeData(result);
          console.log(result);
          // 第一次加载，默认选择第一个组织
          if (treeFlage) {
            handleSelect([result[0].menuID], false);
            setTreeFlag(false);
          }
        }
      })
      .catch(err => {
        setLoading(false);
        message.error(err);
      });
  };
  // 处理数据
  const mapTree = val => {
    const obj = { ...val };
    const hasChild = obj.children.length > 0;
    return {
      title: (
        <div className={styles.title}>
          <div>{obj.text}</div>
          <div className={styles.tip}>
            {obj.menuType === 'MiniAppMenuGroup' && (
              <Tooltip title="新增菜单组" className={styles.fs}>
                <FolderAddTwoTone onClick={() => addMenuGroupTip(obj)} />
              </Tooltip>
            )}
            {obj.menuType === 'MiniAppMenuGroupTwo' && (
              <Tooltip title="新增功能菜单" className={styles.fs}>
                <FileAddTwoTone onClick={() => addMenuTip(obj)} />
              </Tooltip>
            )}
            <Popconfirm
              cancelText="取消"
              okText="确定"
              title={`确定删除${obj.text}？`}
              onConfirm={() => deleteMenuTip(obj)}
              placement="right"
            >
              <Tooltip title="删除菜单" className={styles.fs}>
                <DeleteTwoTone />
              </Tooltip>
            </Popconfirm>
          </div>
        </div>
      ),
      key: obj.menuID,
      icon:
        obj.menuType !== 'MiniAppMenuThree' &&
        obj.menuType !== 'MiniAppMenu' ? (
            <FolderFilled />
          ) : (
          <FileOutlined />
          ),
      menuType: obj.menuType,
      children: hasChild ? obj.children.map(i => mapTree(i)) : [],
    };
  };
  // 树的点击事件
  const handleSelect = (prop, treeNode) => {
    console.log(prop, treeNode);
    if (treeNode) {
      const {
        node,
        node: { menuType },
      } = treeNode;
      console.log(menuType);
      switch (menuType) {
        case 'MiniAppMenuGroup':
          setNodeType(1);
          setAddType(2);
          break;
        case 'MiniAppMenuGroupTwo':
          setNodeType(2);
          setAddType(4);
          break;
        case 'MiniAppMenu':
          setNodeType(3);
          setAddType(3);
          break;
        case 'MiniAppMenuThree':
          setNodeType(4);
          setAddType(4);
          break;
        default:
          break;
      }
    }
    if (prop[0]) {
      setMenuID(prop[0]);
      setSaveID(prop[0]);
    } else {
      setMenuID(saveID);
    }
  };

  const getInfo = id => {
    if (!menuID) {
      return;
    }
    setLoading(true);
    getMenuInfo({
      menuID,
      _version: 9999,
      _dc: Date.now(),
    })
      .then(res => {
        setLoading(false);
        if (res.success) {
          setInfo({ ...res });
        } else {
          notification.error({
            message: '提示',
            duration: 10,
            description: res.message || '获取失败',
          });
        }
        console.log(res, 'resss');
      })
      .catch(err => {
        setLoading(false);
        console.error(err);
      });
  };
  // 删除的回调
  const deleteMenuTip = val => {
    console.log(val, 'val');
    deleteMenu({
      menuID: val.menuID,
      _dc: Date.now(),
      _version: 9999,
    }).then(res => {
      if (res.success) {
        setFlag(flag + 1);
        notification.success({
          message: '提示',
          duration: 3,
          description: '删除成功',
        });
      } else {
        notification.error({
          message: '提示',
          duration: 10,
          description: res.message || '删除成功',
        });
      }
    });
  };
  // 新增菜单组
  const addMenuGroupTip = val => {
    console.log(val, 'addgroup');
    setNodeObj(val);
    setAddVisible(true);
  };
  const rootAddGroup = () => {
    setNodeObj('');
    setNodeType(1);
    setAddType(1);
    setAddVisible(true);
  };
  // 新增功能菜单
  const addMenuTip = val => {
    console.log(val, 'add');
    setNodeObj(val);
    setAddTwoVisible(true);
  };
  const rootAdd = () => {
    setNodeObj('');
    setNodeType(3);
    setAddType(3);
    setAddTwoVisible(true);
  };
  // 提交的回调
  const submitCallback = (prop, item) => {
    console.log(prop, item);
    let obj = { ...prop };
    const parentID = item.menuID ? item.menuID : -1;
    addMenu({
      _dc: Date.now(),
      parentID,
      subSystemValue: 'miniapp',
      _version: 9999,
      ...obj,
    })
      .then(res => {
        if (res.success) {
          setAddVisible(false);
          setAddTwoVisible(false);
          setFlag(flag + 1);
          notification.success({
            message: '提示',
            description: '新增成功',
            duration: 3,
          });
        } else {
          notification.error({
            message: '提示',
            description: res.message || '新增失败',
            duration: 10,
          });
        }
        console.log(res, 'resadd');
      })
      .catch(err => {
        console.error(err);
      });
  };
  // 编辑的回调
  const editSubmitCallback = prop => {
    setLoading(true);
    console.log(prop);
    let obj = { ...prop };
    editMenu({
      _dc: Date.now(),
      menuID,
      subSystemValue: 'miniapp',
      _version: 9999,
      ...obj,
    })
      .then(res => {
        setLoading(false);

        if (res.success) {
          setFlag(flag + 1);
          notification.success({
            message: '提示',
            duration: 3,
            description: '编辑成功',
          });
        } else {
          notification.error({
            message: '提示',
            duration: 3,
            description: res.message || '编辑失败',
          });
        }
        console.log(res, 'resres');
      })
      .catch(err => {
        console.error(err);
        setLoading(false);
      });
  };
  return (
    <Spin spinning={loading} tip="loading...">
      <div
        className={classnames({
          [styles.box]: true,
        })}
      >
        <div
          className={classnames({
            [styles.left]: true,
          })}
        >
          <div
            className={classnames({
              [styles.leftTop]: true,
            })}
          >
            菜单列表
            <div
              className={classnames({
                [styles.tRight]: true,
              })}
            >
              <Tooltip title="新增菜单组">
                <FolderAddTwoTone
                  className={`${styles.icon1} ${styles.icon}`}
                  onClick={() => rootAddGroup()}
                />
              </Tooltip>
              <Tooltip title="新增功能菜单">
                <FileAddTwoTone
                  onClick={() => rootAdd()}
                  className={`${styles.icon2} ${styles.icon}`}
                />
              </Tooltip>
            </div>
          </div>
          {treeData.length > 0 && (
            <Tree
              showIcon
              onSelect={handleSelect}
              treeData={treeData.map(item => mapTree(item))}
              blockNode
              autoExpandParent
              selectedKeys={[menuID]}
              expandedKeys={[menuID]}
            />
          )}
        </div>
        <Modal
          visible={addVisible}
          title="新增菜单组"
          bodyStyle={{ width: '100%', minHeight: '100px' }}
          style={{ top: 20 }}
          width="600px"
          destroyOnClose
          footer={null}
          cancelText="取消"
          okText="确认"
          onCancel={() => setAddVisible(false)}
          onConfirm={() => {
            submitCallback();
          }}
        >
          <AddForm
            nodeType={nodeType}
            nodeObj={nodeObj}
            addType={addType}
            submitCallback={submitCallback}
          />
        </Modal>
        <Modal
          visible={addTwoVisible}
          title="新增功能菜单"
          bodyStyle={{ width: '100%', minHeight: '100px' }}
          style={{ top: 20 }}
          width="600px"
          destroyOnClose
          footer={null}
          cancelText="取消"
          okText="确认"
          onCancel={() => setAddTwoVisible(false)}
        >
          <AddForm
            nodeType={nodeType}
            nodeObj={nodeObj}
            addType={addType}
            submitCallback={submitCallback}
          />
        </Modal>
        <div
          className={classnames({
            [styles.middle]: true,
          })}
        >
          {nodeType && (
            <EditForm
              nodeType={nodeType}
              info={info}
              submitCallback={editSubmitCallback}
            />
          )}
        </div>
      </div>
    </Spin>
  );
};

export default MiniMenu;
