import React, { useState, useEffect } from 'react';
import {
  Row,
  Col,
  Card,
  Input,
  Tooltip,
  Button,
  notification,
  Spin,
  List,
  Space,
} from 'antd';
import { DoubleLeftOutlined, DoubleRightOutlined } from '@ant-design/icons';
import PageContainer from '@/components/BasePageContainer';
import {
  getWebModuleTree,
  chooseUserToStation,
  getUserByStation,
} from '@/services/userCenter/siteManage/api';
import ListCard, {
  checkChildrenByCondition,
  getId,
} from '@/components/CheckGroup';
import styles from '@/pages/userCenter/siteManage/SiteManage.less';
import qs from 'qs';
import classnames from 'classnames';
import AddModal from './AddModal';
import DelModal from './DelModal';
import EditModal from './EditModal';
import userStyles from '../UserManage.less';

const { Search } = Input;
const placeholder = '请输入人员姓名';
const SiteManage = () => {
  const [treeData, setTreeData] = useState([]); // 树结构数据
  const [currentStation, setCurrentStation] = useState({}); // 当前选中站点
  const [searchWord, setSearchWord] = useState(''); // 关键字
  const [modalVisible, setModalVisible] = useState(false); // 新增弹窗
  const [flag, setFlag] = useState(1);
  const [delVisible, setDelVisible] = useState(false); // 删除弹窗
  const [editVisible, setEditVisible] = useState(false); // 修改弹窗
  const [subList, setSubList] = useState([]); // 选中的数组
  const [spinLoading, setSpinLoading] = useState(false);
  const [btnLoading, setBtnLoading] = useState(false);
  const [valueList, setValueList] = useState([]);
  const [dataList, setdataList] = useState([]);
  const [loading, setLoading] = useState(true);
  const [mulu, setMulu] = useState(true);

  useEffect(() => {
    setSpinLoading(true);
    getWebModuleTree({
      userMode: 'super',
      select: '',
      _version: 9999,
      _dc: Date.now(),
      node: -2,
    })
      .then(res => {
        setSpinLoading(false);
        let arr = [];
        if (res) {
          arr.push(res.find(item => item.id === 'Web4StationRoot'));
        }
        if (arr[0]) {
          const stations = arr[0].children;
          setTreeData(stations);
          if (!currentStation.stationID) {
            setCurrentStation(stations[0]);
          } else {
            setCurrentStation(
              stations.find(s => s.stationID === currentStation.stationID) ||
                stations[0],
            );
          }
        }
      })
      .catch(err => {
        setSpinLoading(false);
        console.error(err);
      });
  }, [flag]);
  useEffect(() => {
    if (!currentStation.stationID) return;
    setLoading(true);
    const defaultConfig = {};
    getUserByStation({
      stationID: currentStation.stationID,
      _version: 9999,
      _dc: new Date().getTime(),
    })
      .then(res => {
        const list = [];
        // eslint-disable-next-line no-unused-expressions
        res &&
          res.forEach(item => {
            list.push({ ...defaultConfig, ...item });
          });
        const finalList = buildMap(list);
        setdataList(finalList);
        setValueList(
          finalList
            .map(l =>
              checkChildrenByCondition(
                l,
                it => (it.isChecked ? [getId(it)] : []),
                true,
                'map',
              ).flat(Infinity),
            )
            .flat(Infinity)
            .filter(Boolean),
        );
        setLoading(false);
      })
      .catch(err => {
        setLoading(false);
      });
  }, [currentStation]);

  const buildMap = list => {
    const obj = {
      type: 'widgetGroup',
      searchWord,
      children: '',
      text: '',
      itemid: '',
    };
    let arr = list.map(item => {
      item.id = item.OUID * 10000;
      item.text = item.OUName;
      item.isChecked = false;
      item.type = 'widgetGroup';
      item.children = item.userList.map(u => ({
        ...u,
        text: u.userName,
        type: 'widgetChild',
      }));
      return item;
    });

    console.log(arr);
    return arr.filter(item => item.userList.length > 0);
  };

  // 新增站点
  const handleAdd = e => {
    console.log(e);
    setModalVisible(true);
  };
  // 站点删除
  const handleDel = e => {
    setDelVisible(true);
  };
  // 编辑站点
  const handleEdit = e => {
    setEditVisible(true);
  };
  // 获取搜索框的值
  const handleSearch = value => {
    setSearchWord(value);
  };
  const handleChange = e => {
    const { value } = e.target;
    setSearchWord(value);
  };
  const confirmModal = e => {
    setModalVisible(false);
    setFlag(flag + 1);
  };
  const delModal = () => {
    setDelVisible(false);
    setFlag(flag + 1);
  };
  const editModal = () => {
    setEditVisible(false);
    setFlag(flag + 1);
  };
  const valueCallback = valueObj => {
    setSubList(valueObj);
  };
  const handleCommit = results => {
    setBtnLoading(true);
    chooseUserToStation(
      qs.stringify({
        // userList: String(arr.flat()),
        userList: String(results.flat()),
        stationID: currentStation.stationID,
      }),
      {
        headers: {
          'content-type': 'application/x-www-form-urlencggoded;charset=UTF-8',
        },
      },
    )
      .then(res => {
        setBtnLoading(false);
        if (res.success) {
          notification.success({
            message: '提示',
            duration: 3,
            description: '设置成功',
          });
        } else {
          notification.error({
            message: '提示',
            duration: 15,
            description: res.message,
          });
        }
      })
      .catch(err => {
        setBtnLoading(false);
        console.log(err);
      });
  };
  const handleHide = () => {
    setMulu(!mulu);
  };
  const renderListItem = items =>
    items.map(t => (
      <List.Item
        onClick={() => {
          setCurrentStation(t);
        }}
        key={t.id}
        className={classnames({
          [styles.listItem]: true,
          [styles.selected]: currentStation.id === t.id,
        })}
      >
        {t.text}
      </List.Item>
    ));

  return (
    <PageContainer>
      {/* <Row>
        <Col span={mulu ? 4 : 0}> */}
      <div className={styles.content}>
        <Card
          className={classnames({
            [styles.cardBox]: true,
            [styles.hideBox]: !mulu,
          })}
        >
          <Spin
            tip="loading...."
            spinning={spinLoading}
            style={{ marginTop: '20px' }}
          >
            <div className={userStyles.siteTitle}>
              <span>选择站点：</span>
            </div>
            <List>{renderListItem(treeData)}</List>
          </Spin>
          <AddModal
            visible={modalVisible}
            onCancel={() => setModalVisible(false)}
            confirmModal={confirmModal}
          />
          <DelModal
            visible={delVisible}
            stationId={currentStation.stationID}
            onCancel={() => setDelVisible(false)}
            confirmModal={delModal}
          />
          <EditModal
            visible={editVisible}
            stationObj={currentStation}
            onCancel={() => setEditVisible(false)}
            confirmModal={editModal}
          />
          <div>
            {mulu && (
              <Tooltip title="隐藏站点" className={styles.hide}>
                <DoubleLeftOutlined onClick={() => handleHide()} />
              </Tooltip>
            )}
            {!mulu && (
              <Tooltip title="显示站点" className={styles.hide}>
                <DoubleRightOutlined onClick={() => handleHide()} />
              </Tooltip>
            )}
          </div>
        </Card>
        {/* <div>
            {mulu && (
              <Tooltip title="隐藏站点" className={styles.hide}>
                <DoubleLeftOutlined onClick={() => handleHide()} />
              </Tooltip>
            )}
            {!mulu && (
              <Tooltip title="显示站点" className={styles.hide}>
                <DoubleRightOutlined onClick={() => handleHide()} />
              </Tooltip>
            )}
          </div> */}
        {/* </Col> */}
        {/* <Col span={mulu ? 0 : 1}>
          {mulu && (
            <Tooltip title="隐藏站点" className={styles.hide}>
              <DoubleLeftOutlined onClick={() => handleHide()} />
            </Tooltip>
          )}
          {!mulu && (
            <Tooltip title="显示站点" className={styles.hide}>
              <DoubleRightOutlined onClick={() => handleHide()} />
            </Tooltip>
          )}
        </Col> */}
        {/* <Col span={mulu ? 20 : 23}> */}
        <div
          className={classnames({
            [styles.boxR]: true,
            [styles.boxH]: mulu,
          })}
        >
          <Card
            className={classnames({
              [styles.cardBoxTop]: true,
              [styles.boxH]: mulu,
            })}
          >
            <Row align="middle">
              <Col span={1}>搜索</Col>
              <Col span={8}>
                <Search
                  allowClear
                  placeholder={placeholder}
                  onSearch={handleSearch}
                  onChange={handleChange}
                  enterButton
                />
              </Col>
              <Col span={3} />
              <Col span={8}>
                <Space size="large">
                  <Button
                    type="primary"
                    onClick={() => {
                      handleAdd();
                    }}
                  >
                    新增
                  </Button>
                  <Button
                    type="primary"
                    onClick={() => {
                      handleEdit();
                    }}
                    disabled={!currentStation.stationID || spinLoading}
                  >
                    编辑
                  </Button>
                  <Button
                    danger
                    type="primary"
                    onClick={() => {
                      handleDel(currentStation.stationID);
                    }}
                    disabled={!currentStation.stationID || spinLoading}
                  >
                    删除
                  </Button>
                </Space>
              </Col>
            </Row>
          </Card>
          <Card
            className={classnames({
              [styles.boxH]: mulu,
              [styles.cardBoxR]: true,
            })}
          >
            {currentStation.stationID && (
              <ListCard
                loading={loading}
                checkList={valueList}
                dataList={dataList}
                searchWord={searchWord}
                onCommit={handleCommit}
                btnLoading={btnLoading}
              />
            )}
          </Card>
        </div>
      </div>
      {/* </Col>
      </Row> */}
    </PageContainer>
  );
};

export default SiteManage;
