import React, { useEffect, useState } from 'react';
import PageContainer from '@/components/BasePageContainer';
import { Tabs } from 'antd';
import {
  getWebModuleTree,
  getWebConfigByName,
  getWebconfig,
} from '@/services/webConfig/api';
import styles from './index.less';
import SiteConfig from './components/siteConfigDrawer';
import { appConnector } from '@/containers/App/store';
const { TabPane } = Tabs;

const WebConfigPage = props => {
  const { userMode } = props;
  const [configVisible, setConfigVisible] = useState(false);
  const [loading, setLoading] = useState(false);
  const [webs, setWebs] = useState([]);
  const [curWeb, setCurWeb] = useState(null); // 当前展示的web
  const [configObj, setConfigObj] = useState({}); // 获取当前的web的配置
  const [toEdit, setToEdit] = useState(null); // 编辑展示用的配置

  const hasIntegerate = () => webs.some(w => w.webType === 'integrate');

  useEffect(() => {
    getWebModuleTree(userMode || 'super').then(res => {
      const websArr = [
        res.data
          .filter(d => d.id === 'Web4IntegrateStation')
          .map(r => r.children.map(i => ({ ...i, webType: 'integrate' }))),
        res.data
          .filter(d => d.id === 'Web4SingleStation')
          .map(r => r.children.map(i => ({ ...i, webType: 'single' }))),
      ].flat(2);
      setWebs(websArr);
      setCurWeb(websArr[0]);
      setLoading(false);
    });
  }, []);

  useEffect(() => {
    // eslint-disable-next-line no-unused-expressions
    curWeb &&
      getWebconfig(curWeb.text).then(res => {
        setConfigObj(res);
        setToEdit(res);
      });
  }, [curWeb]);

  const renderTabPane = tabPaneItem => (
    <TabPane key={tabPaneItem.text} tab={tabPaneItem.text}>
      <>
        <span
          onClick={() => {
            setToEdit(configObj);
            setConfigVisible(true);
          }}
        >
          查看配置
        </span>
      </>
    </TabPane>
  );

  const onEdit = (targetKey, action) => {
    // console.log(targetKey, action); // action: add|remove
    switch (action) {
      case 'add':
        setConfigVisible(true);
        break;
      case 'remove':
        break;
      default:
    }
  };

  const onDrawerClose = form => {
    setConfigVisible(false);
  };

  const handleTabChange = v => {
    setCurWeb(webs.find(w => w.text === v));
  };

  return (
    <PageContainer loading={loading}>
      <div className={styles.webConfigContainer}>
        <Tabs type="editable-card" onEdit={onEdit} onChange={handleTabChange}>
          {webs.map(renderTabPane)}
        </Tabs>
        <SiteConfig
          visible={configVisible}
          onClose={onDrawerClose}
          config={toEdit}
          hasIntegerate={hasIntegerate()}
        />
      </div>
    </PageContainer>
  );
};

export default appConnector(WebConfigPage);
